function [] = demo(FileName)

% [] = demo(FileName)
% Demo function to show Petri dish preprocessing.
% Filename is an image file to be processed, in JPG or TIFF format
% Possible dimensions: 560x752, 768x1024, 1536x2048

if nargin<1
    disp('Usage: demo(''FileName'')');
    return
end

% Load image, convert to greyscale
img = LoadImg(FileName);

% Call the preprocessor function
[Dish,DishBW,PetriX,PetriY,R_ROI,TotArea] = DishPreprocessor(img);

% Position of the output display on the screen
scrsz = get(0,'ScreenSize');
height = .6*scrsz(4);
width = .7*scrsz(3);
XGUI = .2*scrsz(3);
YGUI = .1*scrsz(4);
FigPos = [XGUI,YGUI,width,height];

LineWidth=2;

R1Measured = R_ROI;

% Prepare circle marking the region of interest

tmpY = CircleSeg45(R1Measured, 1, 0);
tmpX = 0:(length(tmpY)-1);

ROICircleX = PetriX+[tmpX tmpY(end:-1:1)  tmpY  tmpX(end:-1:1)];
ROICircleY = PetriY+[tmpY tmpX(end:-1:1) -tmpX -tmpY(end:-1:1)];

ROICircleX = [ROICircleX 2*PetriX-ROICircleX(end:-1:1)];
ROICircleY = [ROICircleY ROICircleY(end:-1:1)];

figure('Position',FigPos);

subplot(1,2,1);
% Original image, with the center of the dish and the circle of ROI
image(img);
axis image
axis off
h=gcf;
colormap(gray(256));
set(h,'Name',FileName,'NumberTitle','Off');
hold
plot(ROICircleX+1, ROICircleY+1, '-g');
plot(PetriX,PetriY,'b*');
title('Original image, location of dish center and ROI');
% Thresholded image (only colonies), limited to the circle of ROI
subplot(1,2,2);
image(Dish.*DishBW);
hold
plot(ROICircleX-PetriX+R_ROI+1, ROICircleY-PetriY+R_ROI+1, '-g');
title('Image after thresholding');
axis square
axis off
pause
close
end